@@ -2,6 +2,7 @@ from .app import App
 
 # import pybi.core.styles as styles
 from pybi.core.styles import *
+from pybi.easyEcharts import *
 from pybi.core import Sql
 
 # import pyvisflow.core.user_utils
@@ -21,6 +22,7 @@ __all__ = [
     "box",
     "app",
     "styles",
+    "easy_echarts",
     "to_json",
     "sql",
     "set_dataView",
