@@ -6,6 +6,7 @@ import uuid
 from pathlib import Path
 from zipfile import ZipFile, ZIP_DEFLATED
 import tempfile
+import os
 
 
 if TYPE_CHECKING:
@@ -32,10 +33,16 @@ def ds2sqlite(path: str, dataSources: List[DataSource], clear_data=False):
 
 def ds2sqlite_file_base64(dataSources: List[DataSource], clear_data=False):
 
-    filename = ""
+    filename = None
+    need_remove_temp_files = False
     with tempfile.TemporaryFile() as tp:
         filename = tp.name
 
+    # has a number name in some env
+    if (filename is None) or not isinstance(filename, str):
+        filename = _create_file_name()
+        need_remove_temp_files = True
+
     ds2sqlite(filename, dataSources, clear_data)
 
     zipfile_name = f"{filename}.zip"
@@ -44,4 +51,8 @@ def ds2sqlite_file_base64(dataSources: List[DataSource], clear_data=False):
         myzip.write(filename)
 
     res = file2base64(zipfile_name)
+
+    if need_remove_temp_files:
+        os.remove(filename)
+        os.remove(zipfile_name)
     return res
