@@ -1,7 +1,9 @@
 import re
 
-s_sql_table_name_pat = re.compile(r"(?<=from|join)\s+(\w+\b)", re.I)
-s_sql_fields_head_select_pat = re.compile(r"(?<=select)\s+?(.+?)\s+from", re.I)
+s_sql_table_name_pat = re.compile(r"(?<=from|join)\s+(\w+\b)", re.I | re.DOTALL)
+s_sql_fields_head_select_pat = re.compile(
+    r"(?<=select)\s+?(.+?)\s+from", re.I | re.DOTALL
+)
 
 
 def extract_table_names(sql: str):
